/* SPDX-License-Identifier: GPL-2.0 */
/******************************************************************************
 *
 * Copyright(c) 2007 - 2011 Realtek Corporation. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
 *
 *
 ******************************************************************************/
#ifndef __INC_ODM_REGCONFIG_H_8821C
#define __INC_ODM_REGCONFIG_H_8821C


void
odm_config_rf_reg_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u32					data,
	enum odm_rf_radio_path_e		RF_PATH,
	u32					reg_addr
);

void
odm_config_rf_radio_a_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u32					data
);

void
odm_config_rf_radio_b_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u32					data
);

void
odm_config_mac_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u8					data
);

void
odm_update_agc_big_jump_lmt_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u32					data
);

void
odm_config_bb_agc_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u32					bitmask,
	u32					data
);

void
odm_config_bb_phy_reg_pg_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					band,
	u32					rf_path,
	u32					tx_num,
	u32					addr,
	u32					bitmask,
	u32					data
);

void
odm_config_bb_phy_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u32					addr,
	u32					bitmask,
	u32					data
);

void
odm_config_bb_txpwr_lmt_8821c(
	struct PHY_DM_STRUCT				*p_dm_odm,
	u8					*regulation,
	u8					*band,
	u8					*bandwidth,
	u8					*rate_section,
	u8					*rf_path,
	u8					*channel,
	u8					*power_limit
);

#endif /* RTL8822B_SUPPORT == 1*/
